@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QAction>
 #include <QDialog>
@@ -148,7 +133,7 @@ void ScriptManager::updateActions(const QModelIndexList &selected)
     remove_script->setEnabled(num_removable > 0);
     run_script->setEnabled(selected.count() > 0 && num_not_running > 0);
     stop_script->setEnabled(selected.count() > 0 && num_running > 0);
-    Script *s = 0;
+    Script *s = nullptr;
     if (selected.count() > 0)
         s = model->scriptForIndex(selected.front());
     properties->setEnabled(selected.count() == 1 && s && s->metaInfo().valid());
@@ -201,7 +186,7 @@ void ScriptManager::editScript()
     for (const QModelIndex &idx : sel) {
         Script *s = model->scriptForIndex(idx);
         if (s)
-            new KRun(QUrl::fromLocalFile(s->scriptFile()), 0);
+            new KRun(QUrl::fromLocalFile(s->scriptFile()), nullptr);
     }
 }
 
